<?php

/**
 * Attaches the scripts and data required for MyCludo CMS Overlay.
 */
class CludoLibrary {

  /**
   * MyCludo CMS Overlay Version.
   */
  const VERSION = '1.0.0';

  /**
   * Loads the Cludo CMS plugin script to the HTML.
   *
   * @param array $build
   *   Hierarchical associative array containing data to be rendered.
   */
  public static function attachCmsOverlayScript(array &$build) {
    $build['#attached']['js']['https://customer.cludo.com/scripts/cludo-cms-overlay/' . self::VERSION . '/cludo-cms-overlay.min.js'] = [
      'type' => 'external',
      'scope' => 'footer',
    ];
    $build['#attached']['js'][] = [
      'data' => drupal_get_path('module', 'cludo') . '/js/cludo-main.js',
      'scope' => 'footer',
    ];
    $build['#attached']['js'][] = [
      'type' => 'setting',
      'data' => [
        'cludo' => [
          'version' => VERSION,
        ],
      ],
    ];

  }

  /**
   * Adds the data for the current page.
   *
   * @param array $build
   *   Hierarchical associative array containing data to be rendered.
   * @param string $url
   *   Friendly absolute URL for the current entity.
   */
  public static function setPage(array &$build, $url) {
    $build['#attached']['js'][] = [
      'type' => 'setting',
      'data' => [
        'cludo' => [
          'pageUrl' => self::getAbsolutePath($url),
        ],
      ],
    ];
  }

  /**
   * Get absolute path by the internal URL.
   *
   * @param string $uri
   *   Internal URL.
   *
   * @return string
   *   URL aliased, or the front URL if the content is the frontpage.
   */
  protected static function getAbsolutePath($uri) {
    $frontpage = variable_get('site_frontpage', 'node');

    if ($uri == $frontpage) {
      return url('<front>', ['absolute' => TRUE]);
    }

    $alias = drupal_get_path_alias($uri);
    return url($alias, ['absolute' => TRUE]);
  }

}
